@@ -66,10 +66,10 @@
 
 
 /* Macro used to flag an activity that should be collected */
-#define COLLECT_ACTIVITY(m)	act[get_activity_position(act, m)]->options |= AO_COLLECTED
+#define COLLECT_ACTIVITY(m)	act[get_activity_position(act, m, EXIT_IF_NOT_FOUND)]->options |= AO_COLLECTED
 
 /* Macro used to flag an activity that should be selected */
-#define SELECT_ACTIVITY(m)	act[get_activity_position(act, m)]->options |= AO_SELECTED
+#define SELECT_ACTIVITY(m)	act[get_activity_position(act, m, EXIT_IF_NOT_FOUND)]->options |= AO_SELECTED
 
 
 /*
@@ -116,10 +116,13 @@
 #define AO_F_MEM_DIA		0x00000001
 #define AO_F_MEM_AMT		0x00000002
 #define AO_F_MEM_SWAP		0x00000004
+/* AO_F_MEM_ALL: See opt_flags in struct activity below */
+#define AO_F_MEM_ALL		(AO_F_MEM_AMT << 8)
 
 #define DISPLAY_MEMORY(m)	(((m) & AO_F_MEM_DIA)     == AO_F_MEM_DIA)
 #define DISPLAY_MEM_AMT(m)	(((m) & AO_F_MEM_AMT)     == AO_F_MEM_AMT)
 #define DISPLAY_SWAP(m)		(((m) & AO_F_MEM_SWAP)    == AO_F_MEM_SWAP)
+#define DISPLAY_MEM_ALL(m)	(((m) & AO_F_MEM_ALL)     == AO_F_MEM_ALL)
 
 /* Output flags for option -u [ ALL ] */
 #define AO_F_CPU_DEF		0x00000001
@@ -197,24 +200,26 @@
  */
 #define BITMAP_SIZE(m)	((((m) + 1) / 8) + 1)
 
-#define UTSNAME_LEN		65
-#define TIMESTAMP_LEN		16
-#define HEADER_LINE_LEN		512
+#define UTSNAME_LEN	65
+#define TIMESTAMP_LEN	16
+#define HEADER_LINE_LEN	512
 
 /* Maximum number of args that can be passed to sadc */
 #define MAX_ARGV_NR	32
 
 /* Miscellaneous constants */
-#define USE_SADC	0
-#define USE_SA_FILE	1
-#define NO_TM_START	0
-#define NO_TM_END	0
-#define NO_RESET	0
-#define NON_FATAL	0
-#define FATAL		1
-#define C_SAR		0
-#define C_SADF		1
-#define ALL_ACTIVITIES	~0U
+#define USE_SADC		0
+#define USE_SA_FILE		1
+#define NO_TM_START		0
+#define NO_TM_END		0
+#define NO_RESET		0
+#define NON_FATAL		0
+#define FATAL			1
+#define C_SAR			0
+#define C_SADF			1
+#define ALL_ACTIVITIES		~0U
+#define EXIT_IF_NOT_FOUND	1
+#define RESUME_IF_NOT_FOUND	0
 
 #define SOFT_SIZE	0
 #define HARD_SIZE	1
@@ -379,7 +384,11 @@ struct activity {
 	 */
 	__print_funct_t (*f_json_print) (struct activity *, int, int, unsigned long long);
 	/*
-	 * Header string displayed by sadf -d/-D.
+	 * Header string displayed by sadf -d.
+	 * Header lines for each output (for activities with multiple outputs) are
+	 * separated with a '|' character.
+	 * For a given output, the first field corresponding to extended statistics
+	 * (eg. -r ALL) begins with a '&' character.
 	 */
 	char *hdr_line;
 	/*
@@ -427,6 +436,10 @@ struct activity {
 	/*
 	 * Optional flags for activity. This is eg. used when AO_MULTIPLE_OUTPUTS
 	 * option is set.
+	 * 0x0001 - 0x0080 : Multiple outputs (eg. AO_F_MEM_AMT, AO_F_MEM_SWAP...)
+	 * 0x0100 - 0x8000 : If bit set then display complete header (hdr_line) for
+	 *                   corresponding output
+	 * 0x010000+       : Optional flags
 	 */
 	unsigned int opt_flags;
 	/*
@@ -494,6 +507,9 @@ struct activity {
 /* Previous datafile format magic number used by older sysstat versions */
 #define PREVIOUS_FORMAT_MAGIC	0x2171
 
+/* Padding in file_magic structure. See below. */
+#define FILE_MAGIC_PADDING	63
+
 /* Structure for file magic header data */
 struct file_magic {
 	/*
@@ -525,7 +541,7 @@ struct file_magic {
 	/*
 	 * Padding. Reserved for future use while avoiding a format change.
 	 */
-	unsigned char pad[63];
+	unsigned char pad[FILE_MAGIC_PADDING];
 };
 
 #define FILE_MAGIC_SIZE	(sizeof(struct file_magic))
@@ -852,7 +868,7 @@ extern void
 extern int
 	get_activity_nr(struct activity * [], unsigned int, int);
 extern int
-	get_activity_position(struct activity * [], unsigned int);
+	get_activity_position(struct activity * [], unsigned int, int);
 extern char *
 	get_devname(unsigned int, unsigned int, int);
 extern void
