@@ -84,7 +84,8 @@ void allocate_structures(struct activity *act[])
 	for (i = 0; i < NR_ACT; i++) {
 		if (act[i]->nr > 0) {
 			for (j = 0; j < 3; j++) {
-				SREALLOC(act[i]->buf[j], void, act[i]->msize * act[i]->nr * act[i]->nr2);
+				SREALLOC(act[i]->buf[j], void,
+						(size_t) act[i]->msize * (size_t) act[i]->nr * (size_t) act[i]->nr2);
 			}
 		}
 	}
@@ -333,11 +334,12 @@ int parse_timestamp(char *argv[], int *opt, struct tstamp *tse,
 	char timestamp[9];
 
 	if ((argv[++(*opt)]) && (strlen(argv[*opt]) == 8)) {
-		strcpy(timestamp, argv[(*opt)++]);
+		strncpy(timestamp, argv[(*opt)++], 8);
 	}
 	else {
-		strcpy(timestamp, def_timestamp);
+		strncpy(timestamp, def_timestamp, 8);
 	}
+	timestamp[8] = '\0';
 
 	return decode_timestamp(timestamp, tse);
 }
@@ -416,7 +418,7 @@ void guess_sa_name(char *sa_dir, struct tm *rectime, int *sa_name)
 void set_default_file(char *datafile, int d_off, int sa_name)
 {
 	char sa_dir[MAX_FILE_LEN];
-	struct tm rectime;
+	struct tm rectime = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL};
 
 	/* Set directory where daily data files will be saved */
 	if (datafile[0]) {
@@ -911,6 +913,7 @@ void free_bitmaps(struct activity *act[])
  * IN:
  * @act		Array of activities.
  * @act_flag	Activity flag to look for.
+ * @stop	TRUE if sysstat should exit when activity is not found.
  *
  * RETURNS:
  * Position of activity in array, or -1 if not found (this may happen when
@@ -918,19 +921,20 @@ void free_bitmaps(struct activity *act[])
  * sysstat).
  ***************************************************************************
  */
-int get_activity_position(struct activity *act[], unsigned int act_flag)
+int get_activity_position(struct activity *act[], unsigned int act_flag, int stop)
 {
 	int i;
 
 	for (i = 0; i < NR_ACT; i++) {
 		if (act[i]->id == act_flag)
-			break;
+			return i;
 	}
 
-	if (i == NR_ACT)
-		return -1;
+	if (stop) {
+		PANIC((int) act_flag);
+	}
 
-	return i;
+	return -1;
 }
 
 /*
@@ -957,8 +961,8 @@ int get_activity_nr(struct activity *act[], unsigned int option, int count_outpu
 		if ((act[i]->options & option) == option) {
 
 			if (HAS_MULTIPLE_OUTPUTS(act[i]->options) && count_outputs) {
-				for (msk = 1; msk < 0x10; msk <<= 1) {
-					if (act[i]->opt_flags & msk) {
+				for (msk = 1; msk < 0x100; msk <<= 1) {
+					if ((act[i]->opt_flags & 0xff) & msk) {
 						n++;
 					}
 				}
@@ -1008,7 +1012,7 @@ void select_default_activity(struct activity *act[])
 {
 	int p;
 
-	p = get_activity_position(act, A_CPU);
+	p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
 
 	/* Default is CPU activity... */
 	if (!get_activity_nr(act, AO_SELECTED, COUNT_ACTIVITIES)) {
@@ -1160,12 +1164,13 @@ void copy_structures(struct activity *act[], unsigned int id_seq[],
 		if (!id_seq[i])
 			continue;
 
-		if (((p = get_activity_position(act, id_seq[i])) < 0) ||
-		    (act[p]->nr < 1) || (act[p]->nr2 < 1)) {
+		p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
+		if ((act[p]->nr < 1) || (act[p]->nr2 < 1)) {
 			PANIC(1);
 		}
 
-		memcpy(act[p]->buf[dest], act[p]->buf[src], act[p]->msize * act[p]->nr * act[p]->nr2);
+		memcpy(act[p]->buf[dest], act[p]->buf[src],
+		       (size_t) act[p]->msize * (size_t) act[p]->nr * (size_t) act[p]->nr2);
 	}
 }
 
@@ -1186,16 +1191,18 @@ void read_file_stat_bunch(struct activity *act[], int curr, int ifd, int act_nr,
 {
 	int i, j, k, p;
 	struct file_activity *fal = file_actlst;
+	off_t offset;
 
 	for (i = 0; i < act_nr; i++, fal++) {
 
-		if (((p = get_activity_position(act, fal->id)) < 0) ||
+		if (((p = get_activity_position(act, fal->id, RESUME_IF_NOT_FOUND)) < 0) ||
 		    (act[p]->magic != fal->magic)) {
 			/*
 			 * Ignore current activity in file, which is unknown to
 			 * current sysstat version or has an unknown format.
 			 */
-			if (lseek(ifd, fal->size * fal->nr * fal->nr2, SEEK_CUR) < (fal->size * fal->nr * fal->nr2)) {
+			offset = (off_t) fal->size * (off_t) fal->nr * (off_t) fal->nr2;
+			if (lseek(ifd, offset, SEEK_CUR) < offset) {
 				close(ifd);
 				perror("lseek");
 				exit(2);
@@ -1216,7 +1223,7 @@ void read_file_stat_bunch(struct activity *act[], int curr, int ifd, int act_nr,
 			sa_fread(ifd, act[p]->buf[curr], act[p]->fsize * act[p]->nr * act[p]->nr2, HARD_SIZE);
 		}
 		else {
-			PANIC(act[p]->nr);
+			PANIC(p);
 		}
 	}
 }
@@ -1332,7 +1339,7 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[],
 			handle_invalid_sa_file(ifd, file_magic, dfile, 0);
 		}
 
-		if ((p = get_activity_position(act, fal->id)) < 0)
+		if ((p = get_activity_position(act, fal->id, RESUME_IF_NOT_FOUND)) < 0)
 			/* Unknown activity */
 			continue;
 
@@ -1435,14 +1442,15 @@ int reallocate_vol_act_structures(struct activity *act[], unsigned int act_nr,
 {
 	int j, p;
 
-	if ((p = get_activity_position(act, act_id)) < 0)
+	if ((p = get_activity_position(act, act_id, RESUME_IF_NOT_FOUND)) < 0)
 		/* Ignore unknown activity */
 		return -1;
 
 	act[p]->nr = act_nr;
 
 	for (j = 0; j < 3; j++) {
-		SREALLOC(act[p]->buf[j], void, act[p]->msize * act[p]->nr * act[p]->nr2);
+		SREALLOC(act[p]->buf[j], void,
+			 (size_t) act[p]->msize * (size_t) act[p]->nr * (size_t) act[p]->nr2);
 	}
 
 	return 0;
@@ -1520,23 +1528,27 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 	int i, p;
 
 	for (i = 1; *(argv[*opt] + i); i++) {
+		/*
+		 * Note: argv[*opt] contains something like "-BruW"
+		 *     *(argv[*opt] + i) will contain 'B', 'r', etc.
+		 */
 
 		switch (*(argv[*opt] + i)) {
 
 		case 'A':
 			select_all_activities(act);
 
-			/* Force '-P ALL -I XALL' */
+			/* Force '-P ALL -I XALL -r ALL -u ALL' */
 
-			p = get_activity_position(act, A_MEMORY);
+			p = get_activity_position(act, A_MEMORY, EXIT_IF_NOT_FOUND);
 			act[p]->opt_flags |= AO_F_MEM_AMT + AO_F_MEM_DIA +
-					     AO_F_MEM_SWAP;
+					     AO_F_MEM_SWAP + AO_F_MEM_ALL;
 
-			p = get_activity_position(act, A_IRQ);
+			p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
 			set_bitmap(act[p]->bitmap->b_array, ~0,
 				   BITMAP_SIZE(act[p]->bitmap->b_size));
 
-			p = get_activity_position(act, A_CPU);
+			p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
 			set_bitmap(act[p]->bitmap->b_array, ~0,
 				   BITMAP_SIZE(act[p]->bitmap->b_size));
 			act[p]->opt_flags = AO_F_CPU_ALL;
@@ -1563,7 +1575,7 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 			break;
 
 		case 'H':
-			p = get_activity_position(act, A_HUGE);
+			p = get_activity_position(act, A_HUGE, EXIT_IF_NOT_FOUND);
 			act[p]->options   |= AO_SELECTED;
 			break;
 
@@ -1601,19 +1613,24 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 			break;
 
 		case 'r':
-			p = get_activity_position(act, A_MEMORY);
+			p = get_activity_position(act, A_MEMORY, EXIT_IF_NOT_FOUND);
 			act[p]->options   |= AO_SELECTED;
 			act[p]->opt_flags |= AO_F_MEM_AMT;
+			if (!*(argv[*opt] + i + 1) && argv[*opt + 1] && !strcmp(argv[*opt + 1], K_ALL)) {
+				(*opt)++;
+				act[p]->opt_flags |= AO_F_MEM_ALL;
+				return 0;
+			}
 			break;
 
 		case 'R':
-			p = get_activity_position(act, A_MEMORY);
+			p = get_activity_position(act, A_MEMORY, EXIT_IF_NOT_FOUND);
 			act[p]->options   |= AO_SELECTED;
 			act[p]->opt_flags |= AO_F_MEM_DIA;
 			break;
 
 		case 'S':
-			p = get_activity_position(act, A_MEMORY);
+			p = get_activity_position(act, A_MEMORY, EXIT_IF_NOT_FOUND);
 			act[p]->options   |= AO_SELECTED;
 			act[p]->opt_flags |= AO_F_MEM_SWAP;
 			break;
@@ -1633,7 +1650,7 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 			break;
 
 		case 'u':
-			p = get_activity_position(act, A_CPU);
+			p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
 			act[p]->options |= AO_SELECTED;
 			if (!*(argv[*opt] + i + 1) && argv[*opt + 1] && !strcmp(argv[*opt + 1], K_ALL)) {
 				(*opt)++;
@@ -1851,7 +1868,7 @@ int parse_sar_I_opt(char *argv[], int *opt, struct activity *act[])
 	char *t;
 
 	/* Select interrupt activity */
-	p = get_activity_position(act, A_IRQ);
+	p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
 	act[p]->options |= AO_SELECTED;
 
 	for (t = strtok(argv[*opt], ","); t; t = strtok(NULL, ",")) {
@@ -1909,7 +1926,7 @@ int parse_sa_P_opt(char *argv[], int *opt, unsigned int *flags, struct activity
 	int i, p;
 	char *t;
 
-	p = get_activity_position(act, A_CPU);
+	p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
 
 	if (argv[++(*opt)]) {
 
@@ -1960,7 +1977,7 @@ double compute_ifutil(struct stats_net_dev *st_net_dev, double rx, double tx)
 
 	if (st_net_dev->speed) {
 
-		speed = st_net_dev->speed * 1000000;
+		speed = (unsigned long long) st_net_dev->speed * 1000000;
 
 		if (st_net_dev->duplex == C_DUPLEX_FULL) {
 			/* Full duplex */
