@@ -434,10 +434,10 @@ void write_textual_comments(int curr, int use_tm_start, int use_tm_end, int tab,
  */
 void list_fields(unsigned int act_id)
 {
-	int i;
+	int i, j;
 	unsigned int msk;
 	char *hl;
-	char hline[HEADER_LINE_LEN];
+	char hline[HEADER_LINE_LEN] = "";
 
 	printf("# hostname;interval;timestamp");
 
@@ -455,10 +455,27 @@ void list_fields(unsigned int act_id)
 			}
 			else {
 				msk = 1;
-				strcpy(hline, act[i]->hdr_line);
+				strncpy(hline, act[i]->hdr_line, HEADER_LINE_LEN - 1);
+				hline[HEADER_LINE_LEN - 1] = '\0';
 				for (hl = strtok(hline, "|"); hl; hl = strtok(NULL, "|"), msk <<= 1) {
-					if ((hl != NULL) && (act[i]->opt_flags & msk)) {
-						printf(";%s", hl);
+					if ((hl != NULL) && ((act[i]->opt_flags & 0xff) & msk)) {
+						if (strchr(hl, '&')) {
+							j = strcspn(hl, "&");
+							if ((act[i]->opt_flags & 0xff00) & (msk << 8)) {
+								/* Display whole header line */
+								*(hl + j) = ';';
+								printf(";%s", hl);
+							}
+							else {
+								/* Display only the first part of the header line */
+								*(hl + j) = '\0';
+								printf(";%s", hl);
+							}
+							*(hl + j) = '&';
+						}
+						else {
+							printf(";%s", hl);
+						}
 						if ((act[i]->nr > 1) && DISPLAY_HORIZONTALLY(flags)) {
 							printf("[...]");
 						}
@@ -1007,8 +1024,8 @@ void textual_display_loop(int ifd, struct file_activity *file_actlst, char *dfil
 			  struct tm *rectime, struct tm *loctime, char *file)
 {
 	int curr, tab = 0, rtype;
-	int eosaf = TRUE, next, reset = FALSE;
-	__nr_t save_act_nr[NR_ACT];
+	int eosaf, next, reset = FALSE;
+	__nr_t save_act_nr[NR_ACT] = {0};
 	unsigned int new_cpu_nr;
 	long cnt = 1;
 	off_t fpos;
@@ -1361,10 +1378,7 @@ void main_display_loop(int ifd, struct file_activity *file_actlst, __nr_t cpu_nr
 				if (!id_seq[i])
 					continue;
 
-				if ((p = get_activity_position(act, id_seq[i])) < 0) {
-					/* Should never happen */
-					PANIC(1);
-				}
+				p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
 				if (!IS_SELECTED(act[p]->options))
 					continue;
 
@@ -1379,9 +1393,9 @@ void main_display_loop(int ifd, struct file_activity *file_actlst, __nr_t cpu_nr
 
 					optf = act[p]->opt_flags;
 
-					for (msk = 1; msk < 0x10; msk <<= 1) {
-						if (act[p]->opt_flags & msk) {
-							act[p]->opt_flags &= msk;
+					for (msk = 1; msk < 0x100; msk <<= 1) {
+						if ((act[p]->opt_flags & 0xff) & msk) {
+							act[p]->opt_flags &= (0xffffff00 + msk);
 
 							rw_curr_act_stats(ifd, fpos, &curr, &cnt, &eosaf,
 									  act[p]->id, &reset, file_actlst,
@@ -1449,7 +1463,7 @@ void read_stats_from_file(char dfile[])
 			  &file_actlst, id_seq, ignore);
 
 	/* Now pick up number of proc for this file */
-	cpu_nr = act[get_activity_position(act, A_CPU)]->nr;
+	cpu_nr = act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr;
 
 	if (DISPLAY_HDR_ONLY(flags)) {
 		if (*fmt[f_position]->f_header) {
