@@ -662,9 +662,9 @@ __printf_funct_t print_hdr_header(int *tab, int action, char *dfile,
 		for (i = 0; i < NR_ACT; i++) {
 			if (!id_seq[i])
 				continue;
-			if ((p = get_activity_position(act, id_seq[i])) < 0) {
-				PANIC(id_seq[i]);
-			}
+
+			p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
+
 			printf("%02d: %s\t(x%d)", act[p]->id, act[p]->name, act[p]->nr);
 			if (act[p]->f_count2 || (act[p]->nr2 > 1)) {
 				printf("\t(x%d)", act[p]->nr2);
