@@ -108,7 +108,8 @@ void usage(char *progname)
 	print_usage_title(stderr, progname);
 	fprintf(stderr, _("Options are:\n"
 			  "[ -A ] [ -B ] [ -b ] [ -C ] [ -D ] [ -d ] [ -F ] [ -H ] [ -h ] [ -p ] [ -q ]\n"
-			  "[ -R ] [ -r ] [ -S ] [ -t ] [ -u [ ALL ] ] [ -V ] [ -v ] [ -W ] [ -w ] [ -y ]\n"
+			  "[ -R ] [ -r [ ALL ] ] [ -S ] [ -t ] [ -u [ ALL ] ] [ -V ] [ -v ] [ -W ]\n"
+			  "[ -w ] [ -y ]\n"
 			  "[ -I { <int> [,...] | SUM | ALL | XALL } ] [ -P { <cpu> [,...] | ALL } ]\n"
 			  "[ -m { <keyword> [,...] | ALL } ] [ -n { <keyword> [,...] | ALL } ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ]\n"
@@ -168,7 +169,8 @@ void display_help(char *progname)
 		 "\t\tUDP6\tUDP traffic\t(v6)\n"));
 	printf(_("\t-q\tQueue length and load average statistics\n"));
 	printf(_("\t-R\tMemory statistics\n"));
-	printf(_("\t-r\tMemory utilization statistics\n"));
+	printf(_("\t-r [ ALL ]\n"
+		 "\tMemory utilization statistics\n"));
 	printf(_("\t-S\tSwap space utilization statistics\n"));
 	printf(_("\t-u [ ALL ]\n"
 		 "\t\tCPU utilization statistics\n"));
@@ -389,7 +391,7 @@ void write_stats_avg(int curr, int read_from_file, unsigned int act_id)
 	static __nr_t cpu_nr = -1;
 
 	if (cpu_nr < 0)
-		cpu_nr = act[get_activity_position(act, A_CPU)]->nr;
+		cpu_nr = act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr;
 
 	/* Interval value in jiffies */
 	g_itv = get_interval(record_hdr[2].uptime, record_hdr[curr].uptime);
@@ -461,7 +463,7 @@ int write_stats(int curr, int read_from_file, long *cnt, int use_tm_start,
 	static __nr_t cpu_nr = -1;
 
 	if (cpu_nr < 0)
-		cpu_nr = act[get_activity_position(act, A_CPU)]->nr;
+		cpu_nr = act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr;
 
 	if (reset_cd) {
 		/*
@@ -566,7 +568,8 @@ void write_stats_startup(int curr)
 
 	for (i = 0; i < NR_ACT; i++) {
 		if (IS_SELECTED(act[i]->options) && (act[i]->nr > 0)) {
-			memset(act[i]->buf[!curr], 0, act[i]->msize * act[i]->nr * act[i]->nr2);
+			memset(act[i]->buf[!curr], 0,
+			       (size_t) act[i]->msize * (size_t) act[i]->nr * (size_t) act[i]->nr2);
 		}
 	}
 
@@ -697,9 +700,7 @@ void read_sadc_stat_bunch(int curr)
 
 		if (!id_seq[i])
 			continue;
-		if ((p = get_activity_position(act, id_seq[i])) < 0) {
-			PANIC(1);
-		}
+		p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
 
 		if (sa_read(act[p]->buf[curr], act[p]->fsize * act[p]->nr * act[p]->nr2)) {
 			print_read_error();
@@ -737,7 +738,7 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 	int p, reset_cd;
 	unsigned long lines = 0;
 	unsigned char rtype;
-	int davg = 0, next, inc = -2;
+	int davg = 0, next, inc;
 
 	if (lseek(ifd, fpos, SEEK_SET) < fpos) {
 		perror("lseek");
@@ -753,18 +754,13 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 	*cnt  = count;
 
 	/* Assess number of lines printed */
-	if ((p = get_activity_position(act, act_id)) >= 0) {
-		if (act[p]->bitmap) {
-			inc = count_bits(act[p]->bitmap->b_array,
-					 BITMAP_SIZE(act[p]->bitmap->b_size));
-		}
-		else {
-			inc = act[p]->nr;
-		}
+	p = get_activity_position(act, act_id, EXIT_IF_NOT_FOUND);
+	if (act[p]->bitmap) {
+		inc = count_bits(act[p]->bitmap->b_array,
+				 BITMAP_SIZE(act[p]->bitmap->b_size));
 	}
-	if (inc < 0) {
-		/* Should never happen */
-		PANIC(inc);
+	else {
+		inc = act[p]->nr;
 	}
 
 	reset_cd = 1;
@@ -879,7 +875,7 @@ void read_header_data(void)
 			print_read_error();
 		}
 
-		p = get_activity_position(act, file_act.id);
+		p = get_activity_position(act, file_act.id, RESUME_IF_NOT_FOUND);
 
 		if ((p < 0) || (act[p]->fsize != file_act.size)
 			    || !file_act.nr
@@ -933,7 +929,7 @@ void read_stats_from_file(char from_file[])
 
 	/* Print report header */
 	print_report_hdr(flags, &rectime, &file_hdr,
-			 act[get_activity_position(act, A_CPU)]->nr);
+			 act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr);
 
 	/* Read system statistics from file */
 	do {
@@ -990,10 +986,7 @@ void read_stats_from_file(char from_file[])
 			if (!id_seq[i])
 				continue;
 
-			if ((p = get_activity_position(act, id_seq[i])) < 0) {
-				/* Should never happen */
-				PANIC(1);
-			}
+			p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
 			if (!IS_SELECTED(act[p]->options))
 				continue;
 
@@ -1007,9 +1000,9 @@ void read_stats_from_file(char from_file[])
 
 				optf = act[p]->opt_flags;
 
-				for (msk = 1; msk < 0x10; msk <<= 1) {
-					if (act[p]->opt_flags & msk) {
-						act[p]->opt_flags &= msk;
+				for (msk = 1; msk < 0x100; msk <<= 1) {
+					if ((act[p]->opt_flags & 0xff) & msk) {
+						act[p]->opt_flags &= (0xffffff00 + msk);
 
 						handle_curr_act_stats(ifd, fpos, &curr, &cnt,
 								      &eosaf, rows, act[p]->id,
@@ -1062,7 +1055,7 @@ void read_stats(void)
 {
 	int curr = 1;
 	unsigned long lines;
-	unsigned int rows = 23;
+	unsigned int rows;
 	int dis_hdr = 0;
 
 	/* Don't buffer data if redirected to a pipe... */
@@ -1086,7 +1079,7 @@ void read_stats(void)
 
 	/* Print report header */
 	print_report_hdr(flags, &rectime, &file_hdr,
-			 act[get_activity_position(act, A_CPU)]->nr);
+			 act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr);
 
 	/* Read system statistics sent by the data collector */
 	read_sadc_stat_bunch(0);
@@ -1101,7 +1094,7 @@ void read_stats(void)
 
 	/* Set a handler for SIGINT */
 	memset(&int_act, 0, sizeof(int_act));
-	int_act.sa_handler = (void *) int_handler;
+	int_act.sa_handler = int_handler;
 	int_act.sa_flags = SA_RESTART;
 	sigaction(SIGINT, &int_act, NULL);
 
